@@ -1,19 +1,22 @@
 from __future__ import division
 import abc
-import numpy as np
 from copy import deepcopy
-from skimage.transform import pyramid_gaussian
-from skimage.transform.pyramids import _smooth
+
+import numpy as np
+from scipy.misc import imrotate
 import scipy.linalg
 import PIL.Image as PILImage
-from scipy.misc import imrotate
+from skimage.transform import pyramid_gaussian
+from skimage.transform.pyramids import _smooth
 
 from menpo.base import Vectorizable
 from menpo.landmark import Landmarkable
-from menpo.transform import Translation, NonUniformScale, UniformScale, \
-    AlignmentUniformScale
+from menpo.transform import (Translation, NonUniformScale, UniformScale,
+                             AlignmentUniformScale)
 from menpo.visualize.base import Viewable, ImageViewer
-from menpo.image.feature import FeatureExtraction
+
+from .feature import ImageFeatures
+from .interpolation import scipy_interpolation
 
 
 class ImageBoundaryError(ValueError):
@@ -77,7 +80,7 @@ class Image(Vectorizable, Landmarkable, Viewable):
                              "was provided".format(image_data.ndim))
         self.pixels = image_data
         # add FeatureExtraction functionality
-        self.features = FeatureExtraction(self)
+        self.features = ImageFeatures(self)
 
     @classmethod
     def _init_with_channel(cls, image_data_with_channel, **kwargs):
@@ -133,7 +136,7 @@ class Image(Vectorizable, Landmarkable, Viewable):
             A new image of the requested size.
         """
         # Ensure that the '+' operator means concatenate tuples
-        shape = tuple(np.ceil(shape))
+        shape = tuple(np.ceil(shape).astype(np.int))
         if fill == 0:
             pixels = np.zeros(shape + (n_channels,), dtype=dtype)
         else:
@@ -289,6 +292,7 @@ class Image(Vectorizable, Landmarkable, Viewable):
             An array or a list of arrays corresponding to the above histograms
             that store the bins' edges.
             The result in the case of list of arrays can be visualized as:
+
                 for k in range(len(hist)):
                     plt.subplot(1,len(hist),k)
                     width = 0.7 * (bin_edges[k][1] - bin_edges[k][0])
@@ -465,7 +469,7 @@ class Image(Vectorizable, Landmarkable, Viewable):
             # points have been constrained and the user didn't want this -
             raise ImageBoundaryError(min_indices, max_indices,
                                      min_bounded, max_bounded)
-        slices = [slice(min_i, max_i)
+        slices = [slice(int(min_i), int(max_i))
                   for min_i, max_i in
                   zip(list(min_bounded), list(max_bounded))]
         self.pixels = self.pixels[slices].copy()
@@ -671,7 +675,6 @@ class Image(Vectorizable, Landmarkable, Viewable):
         warped_image : type(self)
             A copy of this image, warped.
         """
-        from menpo.interpolation import scipy_interpolation
         # configure the interpolator we are going to use for the warp
         # currently only scipy is supported but in the future we may have CUDA
         if interpolator == 'scipy':
@@ -686,7 +689,7 @@ class Image(Vectorizable, Landmarkable, Viewable):
                 "(they must match)".format(self.n_dims, transform.n_dims))
 
         template_points = template_mask.true_indices
-        points_to_sample = transform.apply(template_points).T
+        points_to_sample = transform.apply(template_points)
         # we want to sample each channel in turn, returning a vector of sampled
         # pixels. Store those in a (n_pixels, n_channels) array.
         sampled_pixel_values = _interpolator(self.pixels, points_to_sample,
@@ -1057,7 +1060,9 @@ class Image(Vectorizable, Landmarkable, Viewable):
         ----------
         mode : {'average', 'luminosity', 'channel'}
             'luminosity' - Calculates the luminance using the CCIR 601 formula
+
                 ``Y' = 0.2989 R' + 0.5870 G' + 0.1140 B'``
+
             'average' - intensity is an equal average of all three channels
             'channel' - a specific channel is used
 
