@@ -1,6 +1,6 @@
 import numpy as np
 from scipy.linalg.blas import dgemm
-from menpo.decomposition import principal_component_decomposition
+from menpo.math import principal_component_decomposition
 from menpo.model.base import MeanInstanceLinearModel
 
 
@@ -47,8 +47,8 @@ class PCAModel(MeanInstanceLinearModel):
             data[i] = sample.as_vector()
 
         eigenvectors, eigenvalues, mean_vector = \
-            principal_component_decomposition(data, whiten=False,
-                                              center=center, bias=bias)
+            principal_component_decomposition(
+                data, whiten=False, center=center, bias=bias, inplace=True)
         self._eigenvalues = eigenvalues
 
         super(PCAModel, self).__init__(eigenvectors, mean_vector, samples[0])
@@ -64,7 +64,7 @@ class PCAModel(MeanInstanceLinearModel):
 
     @n_active_components.setter
     def n_active_components(self, value):
-        value = round(value)
+        value = int(round(value))
         if 0 < value <= self.n_components:
             self._n_components = value
         else:
