@@ -2,8 +2,6 @@ import abc
 import copy
 import numpy as np
 
-from menpo.exception import DimensionalityError
-
 from .base import Homogeneous, HomogFamilyAlignment
 
 
@@ -46,10 +44,10 @@ class Affine(Homogeneous):
         if self.h_matrix is not None:
             # already have a matrix set! The update better be the same size
             if self.n_dims != shape[0] - 1:
-                raise DimensionalityError("Trying to update the homogeneous "
-                                          "matrix to a different dimension")
+                raise ValueError("Trying to update the homogeneous "
+                                 "matrix to a different dimension")
         if shape[0] - 1 not in [2, 3]:
-            raise DimensionalityError("Affine Transforms can only be 2D or 3D")
+            raise ValueError("Affine Transforms can only be 2D or 3D")
         if not (np.allclose(value[-1, :-1], 0) and
                 np.allclose(value[-1, -1], 1)):
             raise ValueError("Bottom row must be [0 0 0 1] or [0, 0, 1]")
@@ -81,7 +79,7 @@ class Affine(Homogeneous):
 
         Returns
         -------
-        transforms: list of :class`DiscreteAffine` that
+        transforms : list of :map:`DiscreteAffine` that
             Equivalent to this affine transform, such that:
 
             ``reduce(lambda x,y: x.chain(y), self.decompose()) == self``
@@ -241,7 +239,7 @@ class Affine(Homogeneous):
         """
         n_points, points_n_dim = points.shape
         if points_n_dim != self.n_dims:
-            raise DimensionalityError(
+            raise ValueError(
                 "Trying to sample jacobian in incorrect dimensions "
                 "(transform is {0}D, sampling at {1}D)".format(
                     self.n_dims, points_n_dim))
@@ -300,16 +298,14 @@ class AlignmentAffine(Affine, HomogFamilyAlignment):
 
     Parameters
     ----------
-
-    source: :class:`menpo.shape.PointCloud`
+    source : :map:`PointCloud`
         The source pointcloud instance used in the alignment
 
-    target: :class:`menpo.shape.PointCloud`
+    target : :map:`PointCloud`
         The target pointcloud instance used in the alignment
 
     Notes
     -----
-
     We want to find the optimal transform M which satisfies
 
         M a = b
